@@ -6,7 +6,7 @@ fitch <- function (tree, data, site="pscore")
         stop("data must be of class phyDat")
     levels <- attr(data, "levels")
     if(inherits(tree,"multiPhylo")){ 
-        TL = attr(tree,"TipLabel")
+        TL <- attr(tree,"TipLabel")
         if (!is.null(TL)){
             data <- subset(data, TL)
             nTips <- length(TL) 
@@ -16,20 +16,20 @@ fitch <- function (tree, data, site="pscore")
         } 
     }
     data <- prepareDataFitch(data) 
-    d = attributes(data)
+    d <- attributes(data)
     data <- as.integer(data)
     attributes(data) <- d
     if(inherits(tree,"phylo")) return(fit.fitch(tree, data, site))
     else{
         if(is.null(attr(tree,"TipLabel"))){
-            tree = unclass(tree)
+            tree <- unclass(tree)
             return(sapply(tree, fit.fitch, data, site))
         }    
         else{
-            tree = .uncompressTipLabel(tree)
-            tree = unclass(tree)
-            tree = lapply(tree, reorder, "postorder")
-            site = ifelse(site == "pscore", 1L, 0L) 
+            tree <- .uncompressTipLabel(tree)
+            tree <- unclass(tree)
+            tree <- lapply(tree, reorder, "postorder")
+            site <- ifelse(site == "pscore", 1L, 0L) 
             on.exit(.C("fitch_free"))
             .C("fitch_init", as.integer(data), as.integer(nTips*nr), as.integer(m), as.double(weight), as.integer(nr)) 
             return(sapply(tree, fast.fitch, nr, site)) 
@@ -44,16 +44,16 @@ fit.fitch <- function (tree, data, returnData = c("pscore", "site", "data"))
         "cladewise") 
         tree <- reorder(tree, "postorder")
     returnData <- match.arg(returnData)
-    nr = attr(data, "nr")
+    nr <- attr(data, "nr")
     node <- tree$edge[, 1]
     edge <- tree$edge[, 2]
-    weight = attr(data, "weight")
-    m = max(tree$edge) 
-    q = length(tree$tip.label)
+    weight <- attr(data, "weight")
+    m <- max(tree$edge) 
+    q <- length(tree$tip.label)
     result <- .Call("FITCH", data[, tree$tip.label], as.integer(nr), as.integer(node), as.integer(edge), as.integer(length(edge)), as.double(weight), as.integer(m), as.integer(q))
     if (returnData == "site") return(result[[2]])
     pscore <- result[[1]]
-    res = pscore
+    res <- pscore
     if (returnData == "data") 
         res <- list(pscore = pscore, dat = result[[3]], site = result[[2]])
     res
@@ -65,9 +65,9 @@ fnodesNew2 <- function (EDGE, nTips, nr)
 {
     node <- EDGE[, 1]
     edge <- EDGE[, 2]
-    n = length(node)
-    m= as.integer(max(EDGE)+1L)
-    m2 = 2L*n
+    n <- length(node)
+    m <- as.integer(max(EDGE)+1L)
+    m2 <- 2L*n
     root0 <- as.integer(node[n]) 
     .Call("FNALL_NNI", as.integer(nr), node, edge, as.integer(n), as.integer(m), as.integer(m2), as.integer(root0))
 }   
@@ -78,8 +78,8 @@ fnodesNew5 <- function (EDGE, nTips, nr, m= as.integer(max(EDGE)+1L))
 {
     node <- EDGE[, 1]
     edge <- EDGE[, 2]
-    n = length(node)              # in C
-    m2 = 2L*n                     # in C
+    n <- length(node)              # in C
+    m2 <- 2L*n                     # in C
     root0 <- as.integer(node[n])  # in C 
     .Call("FNALL5", as.integer(nr), node, edge, as.integer(n), as.integer(m), as.integer(m2), as.integer(root0), PACKAGE="phangorn")
 }   
@@ -92,8 +92,9 @@ random.addition <- function(data, method="fitch")
     label <- names(data)
     nTips <- as.integer(length(label))
     remaining <- as.integer(sample(nTips))  
-    tree <- structure(list(edge = structure(c(rep(nTips+1L, 3), remaining[1:3]), .Dim = c(3L, 2L)), 
-    tip.label = label, Nnode = 1L), .Names = c("edge", "tip.label", "Nnode"), class = "phylo", order = "postorder")
+    tree <- structure(list(edge = structure(c(rep(nTips+1L, 3), remaining[1:3]),
+        .Dim = c(3L, 2L)), tip.label = label, Nnode = 1L), .Names = 
+        c("edge", "tip.label", "Nnode"), class = "phylo", order = "postorder")
     remaining <- remaining[-c(1:3)]
     
     if(nTips==3L) return(tree)
@@ -106,7 +107,7 @@ random.addition <- function(data, method="fitch")
     data <- prepareDataFitch(data) 
     weight <- attr(data, "weight")
 
-    m = nr*(2L*nTips - 2L)
+    m <- nr*(2L*nTips - 2L)
 
     on.exit(.C("fitch_free"))
     .C("fitch_init", as.integer(data), as.integer(nTips*nr), as.integer(m), as.double(weight), as.integer(nr))
@@ -114,14 +115,14 @@ random.addition <- function(data, method="fitch")
     storage.mode(weight) <- "double"
 
     for (i in remaining) {               
-        edge = tree$edge[,2]   
-        score = fnodesNew5(tree$edge, nTips, nr)[edge]      
+        edge <- tree$edge[,2]   
+        score <- fnodesNew5(tree$edge, nTips, nr)[edge]      
         score <- .Call("FITCHTRIP3", as.integer(i), as.integer(nr), as.integer(edge), as.double(score), as.double(Inf))    
-        res = min(score) 
-        nt = which.min(score)  
-        tree = addOne(tree, i, nt) 
+        res <- min(score) 
+        nt <- which.min(score)  
+        tree <- addOne(tree, i, nt) 
         }
-    attr(tree, "pscore") = res
+    attr(tree, "pscore") <- res
     tree 
 }
 
@@ -130,47 +131,47 @@ fast.fitch <- function (tree,  nr, ps = TRUE)
 {
     node <- tree$edge[, 1]
     edge <- tree$edge[, 2]
-    m = max(tree$edge) 
+    m <- max(tree$edge) 
     .Call("FITCH345", as.integer(nr), as.integer(node), as.integer(edge), as.integer(length(edge)), as.integer(m), as.integer(ps))
 }
 
 
 fitch.spr <- function(tree, data){
-  nTips = as.integer(length(tree$tip.label))
-  nr = attr(data, "nr")
-  minp = fast.fitch(tree, nr, TRUE)
-  m=max(tree$edge)
+  nTips <- as.integer(length(tree$tip.label))
+  nr <- attr(data, "nr")
+  minp <- fast.fitch(tree, nr, TRUE)
+  m <- max(tree$edge)
   for(i in 1:nTips){
-    treetmp = dropTip(tree, i)   
-    edge = treetmp$edge[,2] 
+    treetmp <- dropTip(tree, i)   
+    edge <- treetmp$edge[,2] 
 #    score = fnodesNew5(treetmp$edge, nTips, nr)[edge]
     score <- .Call("FNALL6", as.integer(nr), treetmp$edge[,1], edge, as.integer(m+1L), PACKAGE="phangorn")[edge]
     score <- .Call("FITCHTRIP3", as.integer(i), as.integer(nr), as.integer(edge),  as.double(score), as.double(minp))  
     
     if(min(score)<minp){
-      nt = which.min(score)
-      tree = addOne(treetmp, i, nt) 
-      minp=min(score)
+      nt <- which.min(score)
+      tree <- addOne(treetmp, i, nt) 
+      minp <- min(score)
       #   print(paste("new",minp))
     }
   }
   root <- getRoot(tree) 
-  ch = allChildren(tree)
+  ch <- allChildren(tree)
   for(i in (nTips+1L):m){
       if(i!=root){
-          tmp = dropNode(tree, i, all.ch=ch)
+          tmp <- dropNode(tree, i, all.ch=ch)
           if(!is.null(tmp)){
-          edge = tmp[[1]]$edge[,2] 
+          edge <- tmp[[1]]$edge[,2] 
           
-          blub = fast.fitch(tmp[[2]], nr, TRUE)
+          blub <- fast.fitch(tmp[[2]], nr, TRUE)
           score <- .Call("FNALL6", as.integer(nr), tmp[[1]]$edge[,1], edge, as.integer(m+1L), PACKAGE="phangorn")[edge] + blub
 #          score = fnodesNew5(tmp[[1]]$edge, nTips, nr)[edge] + blub
           score <- .Call("FITCHTRIP3", as.integer(i), as.integer(nr), as.integer(edge), as.double(score), as.double(minp))    
           if(min(score)<minp){
-              nt = which.min(score)
-              tree = addOneTree(tmp[[1]], tmp[[2]], nt, tmp[[3]])
+              nt <- which.min(score)
+              tree <- addOneTree(tmp[[1]], tmp[[2]], nt, tmp[[3]])
               minp <- min(score)
-              ch = allChildren(tree)
+              ch <- allChildren(tree)
             }
         }
       }
@@ -180,28 +181,28 @@ fitch.spr <- function(tree, data){
 
 # raus oder richten
 fitch.spr2 <- function(tree, data){
-    nTips = as.integer(length(tree$tip.label))
-    nr = attr(data, "nr")
-    minp = fast.fitch(tree, nr, TRUE)
+    nTips <- as.integer(length(tree$tip.label))
+    nr <- attr(data, "nr")
+    minp <- fast.fitch(tree, nr, TRUE)
     
     changeIndex <- function(x, i, j){
-        x$edge[x$edge == i] = 0L
-        x$edge[x$edge == j] = i
-        x$edge[x$edge == 0L] = j
+        x$edge[x$edge == i] <- 0L
+        x$edge[x$edge == j] <- i
+        x$edge[x$edge == 0L] <- j
         x
     }
     
     
     for(i in 1:nTips){
-        treetmp = dropTip(tree, i)   
-        edge = treetmp$edge[,2] 
-        score = fnodesNew5(treetmp$edge, nTips, nr)[edge]   
+        treetmp <- dropTip(tree, i)   
+        edge <- treetmp$edge[,2] 
+        score <- fnodesNew5(treetmp$edge, nTips, nr)[edge]   
         score <- .Call("FITCHTRIP3", as.integer(i), as.integer(nr), as.integer(edge),  as.double(score), as.double(minp))  
         
         if(min(score)<minp){
-            nt = which.min(score)
-            tree = addOne(treetmp, i, nt) 
-            minp=min(score)
+            nt <- which.min(score)
+            tree <- addOne(treetmp, i, nt) 
+            minp <- min(score)
             #            print(paste("new",minp))
         }
     }
@@ -210,16 +211,16 @@ fitch.spr2 <- function(tree, data){
     root <- getRoot(tree) 
     for(i in (nTips+1L):m){
         if(i!=root){
-            tmp = dropNode(tree, i)
+            tmp <- dropNode(tree, i)
             print(i)
             if(!is.null(tmp)){
-            edge = tmp[[1]]$edge[,2]                          
-            blub = fast.fitch(tmp[[2]], nr, TRUE)
-            score = fnodesNew5(tmp[[1]]$edge, nTips, nr)[edge] + blub
+            edge <- tmp[[1]]$edge[,2]                          
+            blub <- fast.fitch(tmp[[2]], nr, TRUE)
+            score <- fnodesNew5(tmp[[1]]$edge, nTips, nr)[edge] + blub
             score <- .Call("FITCHTRIP3", as.integer(i), as.integer(nr), as.integer(edge), as.double(score), as.double(minp))    
             if(min(score)<minp){
-                nt = which.min(score)
-                tree = addOneTree(tmp[[1]], tmp[[2]], nt, tmp[[3]])
+                nt <- which.min(score)
+                tree <- addOneTree(tmp[[1]], tmp[[2]], nt, tmp[[3]])
                 minp <- min(score)
             }
             }
@@ -247,27 +248,27 @@ fitch.spr2 <- function(tree, data){
 }
            
 indexNNI2 <- function(tree){
-    parent = tree$edge[, 1]
-    child = tree$edge[, 2]
+    parent <- tree$edge[, 1]
+    child <- tree$edge[, 2]
  
-    ind = which(child %in% parent)
-    Nnode = tree$Nnode
-    edgeMatrix = matrix(0L, 6, length(ind))
+    ind <- which(child %in% parent)
+    Nnode <- tree$Nnode
+    edgeMatrix <- matrix(0L, 6, length(ind))
 
-    pvector <- numeric(max(parent))
+    pvector <- integer(max(parent))
     pvector[child] <- parent
     cvector <- allChildren(tree)  
 
     k=0
     for(i in ind){        
-            p1 = parent[i]          
-            p2 = child[i]
-            e34 = cvector[[p2]]
-            ind1 = cvector[[p1]]
-            e12 = ind1[ind1 != p2]
-            if(pvector[p1]) edgeMatrix[, k+1] = c(p1,e12, e34, p2, 1L) 
-            else edgeMatrix[, k+1] = c(e12, e34, p2, 0L)
-            k=k+1
+            p1 <- parent[i]          
+            p2 <- child[i]
+            e34 <- cvector[[p2]]
+            ind1 <- cvector[[p1]]
+            e12 <- ind1[ind1 != p2]
+            if(pvector[p1]) edgeMatrix[, k+1] <- c(p1,e12, e34, p2, 1L) 
+            else edgeMatrix[, k+1] <- c(e12, e34, p2, 0L)
+            k <- k+1
     } 
     cbind(edgeMatrix[c(1,3,2,4,5,6),], edgeMatrix[c(1,4,2,3,5,6),])
 }
@@ -276,26 +277,26 @@ indexNNI2 <- function(tree){
 # weniger Speicher 2 Zeilen weinger 
 fitch.nni <- function (tree, data, ...) 
 {
-    nTips = as.integer(length(tree$tip.label)) # auskommentieren?
+    nTips <- as.integer(length(tree$tip.label)) # auskommentieren?
     INDEX <- indexNNI2(tree)    
-    nr = attr(data, "nr")
+    nr <- attr(data, "nr")
     weight <- attr(data, "weight")
     p0 <- fast.fitch(tree, nr)
     m <- dim(INDEX)[2]    
-    tmp = fnodesNew2(tree$edge, nTips, nr)
+    tmp <- fnodesNew2(tree$edge, nTips, nr)
     pscore <- .C("fitchQuartet", as.integer(INDEX), as.integer(m), as.integer(nr), as.double(tmp[[1]]), as.double(tmp[[2]]), as.double(weight), double(m))[[7]]    
     swap <- 0
     candidates <- pscore < p0
     while (any(candidates)) {
-        ind = which.min(pscore)
-        pscore[ind] = Inf
+        ind <- which.min(pscore)
+        pscore[ind] <- Inf
         tree2 <- changeEdge(tree, INDEX[c(2,3), ind])        
         test <- fast.fitch(tree2, nr)
         if (test >= p0) 
-            candidates[ind] = FALSE
+            candidates[ind] <- FALSE
         if (test < p0) {
             p0 <- test
-            swap = swap + 1
+            swap <- swap + 1
             tree <- tree2
             indi <- which(INDEX[5,] %in% INDEX[1:5, ind])
             candidates[indi] <- FALSE
@@ -308,7 +309,7 @@ fitch.nni <- function (tree, data, ...)
 
 optim.fitch <- function(tree, data, trace=1, rearrangements = "SPR", ...) {
     if(!inherits(tree,"phylo")) stop("tree must be of class phylo") 
-    if(!is.binary.tree(tree)){
+    if(!is.binary(tree)){
         tree <- multi2di(tree)
         attr(tree, "order") <- NULL  
     }
@@ -319,36 +320,36 @@ optim.fitch <- function(tree, data, trace=1, rearrangements = "SPR", ...) {
     if(is.null(attr(tree, "order")) || attr(tree, "order") == "cladewise") tree <- reorder(tree, "postorder")  
     if (class(data)[1] != "phyDat") stop("data must be of class phyDat")
 
-    rt = FALSE
-    nTips = as.integer(length(tree$tip.label))
+    rt <- FALSE
+    nTips <- as.integer(length(tree$tip.label))
 
-    nr = attr(data, "nr")    
+    nr <- attr(data, "nr")    
     pis <- parsinfo(data)
     p0 <- sum(attr(data, "weight")[pis[, 1]] * pis[, 2])
     if (length(pis) > 0) 
         data <- getRows(data, c(1:nr)[-pis[, 1]], TRUE)    
     
-    nr = attr(data, "nr")
+    nr <- attr(data, "nr")
    
     data <- subset(data,tree$tip.label,order(attr(data, "weight"), decreasing=TRUE))   
     dat <- prepareDataFitch(data) 
     weight <- attr(data, "weight")
 
-    m = nr*(2L*nTips - 2L)
+    m <- nr*(2L*nTips - 2L)
     on.exit(.C("fitch_free"))
     .C("fitch_init", as.integer(dat), as.integer(nTips*nr), as.integer(m), as.double(weight), as.integer(nr))
 
     tree$edge.length=NULL
-    swap = 0
-    iter = TRUE
+    swap <- 0
+    iter <- TRUE
     pscore <- fast.fitch(tree, nr)  
     while (iter) {
         res <- fitch.nni(tree, dat, ...)
         tree <- res$tree
         if(trace>1)cat("optimize topology: ", pscore + p0, "-->", res$pscore + p0, 
             "\n")
-        pscore = res$pscore
-        swap = swap + res$swap
+        pscore <- res$pscore
+        swap <- swap + res$swap
         if (res$swap == 0){
             if(rearrangements=="SPR"){
                 tree <- fitch.spr(tree, dat)             
@@ -357,29 +358,29 @@ optim.fitch <- function(tree, data, trace=1, rearrangements = "SPR", ...) {
                 if(pscore < psc+1e-6) iter=FALSE
                 pscore <- psc
             } 
-            else iter = FALSE
+            else iter <- FALSE
         }
     }
     if(trace>0)cat("Final p-score",pscore + p0,"after ",swap, "nni operations \n") 
     if(rt)tree <- ptree(tree, data)  
-    attr(tree, "pscore") = pscore + p0
+    attr(tree, "pscore") <- pscore + p0
     tree
 }
 
 # branch and bound
 getOrder <- function (x) 
 {
-    label = names(x)
-    dm = as.matrix(dist.hamming(x, FALSE))
-    ind = as.vector(which(dm == max(dm), arr.ind = TRUE)[1, ])
-    nTips = as.integer(length(label))
-    added = ind
+    label <- names(x)
+    dm <- as.matrix(dist.hamming(x, FALSE))
+    ind <- as.vector(which(dm == max(dm), arr.ind = TRUE)[1, ])
+    nTips <- as.integer(length(label))
+    added <- ind
     remaining <- c(1:nTips)[-ind]
 
     tree <- structure(list(edge = structure(c(rep(nTips+1L, 3), c(ind, 0L)), .Dim = c(3L, 2L)), tip.label = label, Nnode = 1L), .Names = c("edge", "tip.label", "Nnode"), class = "phylo", order = "postorder")      
 
-    l = length(remaining)
-    res = numeric(l)
+    l <- length(remaining)
+    res <- numeric(l)
 
     nr <- attr(x, "nr")
     storage.mode(nr) <- "integer"
@@ -389,41 +390,41 @@ getOrder <- function (x)
     weight <- attr(data, "weight")
     storage.mode(weight) <- "double"
 
-    m = nr*(2L*nTips - 2L)
+    m <- nr*(2L*nTips - 2L)
 
     on.exit(.C("fitch_free"))
     .C("fitch_init", as.integer(data), as.integer(nTips*nr), as.integer(m), as.double(weight), as.integer(nr))
 
-    for(i in 1:length(remaining)){
+    for(i in seq_along(remaining)){
         tree$edge[3,2]= remaining[i]     
-        res[i] = fast.fitch(tree, nr) 
+        res[i] <- fast.fitch(tree, nr) 
     }
-    tmp = which.max(res)
-    added = c(added, remaining[tmp])
+    tmp <- which.max(res)
+    added <- c(added, remaining[tmp])
     remaining <- remaining[-tmp]
     tree$edge[,2]= added
 
     for (i in 4:(nTips - 1L)) {
-        edge = tree$edge[,2]                 
-        score0 = fnodesNew5(tree$edge, nTips, nr)[edge]        
+        edge <- tree$edge[,2]                 
+        score0 <- fnodesNew5(tree$edge, nTips, nr)[edge]        
         
-        l = length(remaining)
-        res = numeric(l)
-        nt = numeric(l)
-        k = length(added)+1L
+        l <- length(remaining)
+        res <- numeric(l)
+        nt <- numeric(l)
+        k <- length(added)+1L
         for(j in 1:l){
             score <- .Call("FITCHTRIP3", as.integer(remaining[j]), as.integer(nr), as.integer(edge), as.double(score0), as.double(Inf))   
             
 #            score = score0[edge] + psc
-            res[j] = min(score) 
-            nt[j] = which.min(score)
+            res[j] <- min(score) 
+            nt[j] <- which.min(score)
         }
-        tmp = which.max(res)
-        added = c(added, remaining[tmp])        
-        tree = addOne(tree, remaining[tmp], nt[tmp])
+        tmp <- which.max(res)
+        added <- c(added, remaining[tmp])        
+        tree <- addOne(tree, remaining[tmp], nt[tmp])
         remaining <- remaining[-tmp]  
     }
-    added = c(added, remaining) 
+    added <- c(added, remaining) 
     added 
 }
 
@@ -486,8 +487,8 @@ bab <- function (data, tree = NULL, trace = 1, ...)
     # added compressSites
     data <- compressSites(data)
 
-    o = order(attr(data, "weight"), decreasing = TRUE)
-    data = subset(data, , o)
+    o <- order(attr(data, "weight"), decreasing = TRUE)
+    data <- subset(data, , o)
         
     tree <- pratchet(data, start = tree, trace = trace - 1, ...)
     data <- subset(data, tree$tip.label) 
@@ -499,27 +500,27 @@ bab <- function (data, tree = NULL, trace = 1, ...)
     nr <- as.integer(attr(data, "nr"))
     TMP <- UB <- matrix(0, m, nr)
     for (i in 4:m) {
-        TMP[i, ] = lowerBound(subset(data, inord[1:i]))
-        UB[i, ] = upperBound(subset(data, inord[1:i]))
+        TMP[i, ] <- lowerBound(subset(data, inord[1:i]))
+        UB[i, ] <- upperBound(subset(data, inord[1:i]))
     }
     
     dat_used <- subset(data, inord)
     
     weight <- as.double(attr(data, "weight"))
     data <- prepareDataFitch(data)
-    m = nr*(2L*nTips - 2L)
+    m <- nr*(2L*nTips - 2L)
     on.exit(.C("fitch_free"))
     .C("fitch_init", as.integer(data), as.integer(nTips*nr), as.integer(m), as.double(weight), as.integer(nr))
-    mmsAmb = 0
-    mmsAmb = TMP %*% weight  
-    mmsAmb = mmsAmb[nTips] - mmsAmb
-    mms0 = 0
-    if(pBound) mms0 = pBound(dat_used, UB) 
-    mms0 = mms0 + mmsAmb
+    mmsAmb <- 0
+    mmsAmb <- TMP %*% weight  
+    mmsAmb <- mmsAmb[nTips] - mmsAmb
+    mms0 <- 0
+    if(pBound) mms0 <- pBound(dat_used, UB) 
+    mms0 <- mms0 + mmsAmb
     
     
-    minPars = mms0[1]
-    kPars = 0
+    minPars <- mms0[1]
+    kPars <- 0
     
     if (trace) 
         print(paste("lower bound:", p0 + mms0[1]))
@@ -527,8 +528,10 @@ bab <- function (data, tree = NULL, trace = 1, ...)
     if (trace) 
         print(paste("upper bound:", bound + p0))
     
-    startTree <- structure(list(edge = structure(c(rep(nTips+1L, 3), as.integer(inord)[1:3]), .Dim = c(3L, 2L)), 
-                                tip.label = tree$tip.label, Nnode = 1L), .Names = c("edge", "tip.label", "Nnode"), class = "phylo", order = "postorder")
+    startTree <- structure(list(edge = structure(c(rep(nTips+1L, 3), 
+        as.integer(inord)[1:3]), .Dim = c(3L, 2L)), tip.label = tree$tip.label, 
+        Nnode = 1L), .Names = c("edge", "tip.label", "Nnode"), class = "phylo", 
+        order = "postorder")
     
     trees <- vector("list", nTips)
     trees[[3]] <- list(startTree$edge)
@@ -536,8 +539,8 @@ bab <- function (data, tree = NULL, trace = 1, ...)
     
     # index M[i] is neues node fuer edge i+1
     # index L[i] is length(node) tree mit i+1 
-    L = as.integer( 2L*(1L:nTips) -3L ) 
-    M = as.integer( 1L:nTips + nTips - 1L )    
+    L <- as.integer( 2L*(1L:nTips) -3L ) 
+    M <- as.integer( 1L:nTips + nTips - 1L )    
     
     #   PSC = matrix(0, sum(sapply(trees, length)), 3)    
     #   PSC[1,] = c(3,1,0)  
@@ -545,59 +548,59 @@ bab <- function (data, tree = NULL, trace = 1, ...)
     PSC <- matrix(c(3,1,0), 1, 3)
     PSC[1,3] <- fast.fitch(startTree, nr)
     
-    k = 4L
-    Nnode = 1L
-    npsc = 1
+    k <- 4L
+    Nnode <- 1L
+    npsc <- 1
     
-    blub = numeric(nTips)
+    blub <- numeric(nTips)
     
     result <- list() 
     while (npsc > 0) {
-        a = PSC[npsc,1]
-        b = PSC[npsc,2]
-        PSC = PSC[-npsc,, drop=FALSE]  
+        a <- PSC[npsc,1]
+        b <- PSC[npsc,2]
+        PSC <- PSC[-npsc,, drop=FALSE]  
         npsc <- npsc - 1L        
         tmpTree <- trees[[a]][[b]]
-        edge = tmpTree[,2]  
-        score = fnodesNew5(tmpTree, nTips, nr, M[a])[edge] + mms0[a+1L] 
+        edge <- tmpTree[,2]  
+        score <- fnodesNew5(tmpTree, nTips, nr, M[a])[edge] + mms0[a+1L] 
         score <- .Call("FITCHTRIP3", as.integer(inord[a+1L]), as.integer(nr), as.integer(edge), as.double(score), as.double(bound), PACKAGE="phangorn")    
         
-        ms = min(score)
+        ms <- min(score)
         if(ms<=bound){
             if((a+1L)<nTips){
-                ind = (1:L[a])[score<=bound]
-                trees[[a+1]][1:length(ind)] <- .Call("AddOnes", tmpTree, as.integer(inord[a+1L]), as.integer(ind), as.integer(L[a]), as.integer(M[a]), PACKAGE="phangorn") 
-                l = length(ind)
-                #                os = order(score[ind], decreasing=TRUE)     
-                os = seq_len(l)
+                ind <- (1:L[a])[score<=bound]
+                trees[[a+1]][seq_along(ind)] <- .Call("AddOnes", tmpTree, as.integer(inord[a+1L]), as.integer(ind), as.integer(L[a]), as.integer(M[a]), PACKAGE="phangorn") 
+                l <- length(ind)
+                #                os <- order(score[ind], decreasing=TRUE)     
+                os <- seq_len(l)
                 # in C pushback                
-                PSC = rbind(PSC, cbind(rep(a+1, l), os, score[ind] ))
+                PSC <- rbind(PSC, cbind(rep(a+1, l), os, score[ind] ))
                 npsc <- npsc + l
-                blub[a] = blub[a] + l
+                blub[a] <- blub[a] + l
                 #                PSC = rbind(PSC, cbind(rep(a+1, l), os, score[ind][os] ))
             }
             else{
-                ind = which(score==ms) 
+                ind <- which(score==ms) 
                 tmp <- vector("list", length(ind)) 
-                tmp[1:length(ind)] <- .Call("AddOnes", tmpTree, as.integer(inord[a+1L]), as.integer(ind), as.integer(L[a]), as.integer(M[a]), PACKAGE="phangorn")
+                tmp[seq_along(ind)] <- .Call("AddOnes", tmpTree, as.integer(inord[a+1L]), as.integer(ind), as.integer(L[a]), as.integer(M[a]), PACKAGE="phangorn")
                 
                 if(ms < bound){
-                    bound = ms
+                    bound <- ms
                     if(trace)cat("upper bound:", bound + p0, "\n") 
-                    result = tmp    
-                    PSC = PSC[PSC[,3]<(bound+1e-8),]  
-                    npsc = nrow(PSC)
+                    result <- tmp    
+                    PSC <- PSC[PSC[,3]<(bound+1e-8),]  
+                    npsc <- nrow(PSC)
                 }
-                else result = c(result, tmp)  
+                else result <- c(result, tmp)  
             }
         }    
         # not needed here        
 #        npsc = nrow(PSC)
     }
-    for(i in 1:length(result)){
-        result[[i]] = structure(list(edge = result[[i]], Nnode = nTips-2L), .Names = c("edge", "Nnode"), class = "phylo", order = "postorder")
+    for(i in seq_along(result)){
+        result[[i]] <- structure(list(edge = result[[i]], Nnode = nTips-2L), .Names = c("edge", "Nnode"), class = "phylo", order = "postorder")
     }
-    attr(result, "TipLabel") = tree$tip.label
+    attr(result, "TipLabel") <- tree$tip.label
 #    attr(result, "visited") = blub
     class(result) <- "multiPhylo"
     return(result)
@@ -606,15 +609,15 @@ bab <- function (data, tree = NULL, trace = 1, ...)
 
 pBound <- function(x, UB){
     tip <- names(x)
-    att = attributes(x)
-    nc = attr(x, "nc")
-    nr = attr(x, "nr")
-    contrast = attr(x, "contrast")
-    rownames(contrast) = attr(x, "allLevels")
-    colnames(contrast) = attr(x, "levels")
+    att <- attributes(x)
+    nc <- attr(x, "nc")
+    nr <- attr(x, "nr")
+    contrast <- attr(x, "contrast")
+    rownames(contrast) <- attr(x, "allLevels")
+    colnames(contrast) <- attr(x, "levels")
     weight0 <- attr(x, "weight")
-    attr(x, "weight") = rep(1, nr)
-    attr(x, "index") = NULL
+    attr(x, "weight") <- rep(1, nr)
+    attr(x, "index") <- NULL
     
     y <- as.character(x)
     #    states <- apply(y, 2, unique.default)
