@@ -3,27 +3,29 @@
 #
 
 allKids <- function(phy){
-    nTips = as.integer(length(phy$tip.label))
-    lp=nrow(phy$edge)
-    nNode = phy$Nnode
-    .C("AllKids", as.integer(phy$edge[,2]), as.integer(phy$edge[,1]), as.integer(nTips), 
-       as.integer(nNode), as.integer(lp), integer(lp), integer(nNode+1L),integer(nNode))
+    nTips <- as.integer(length(phy$tip.label))
+    lp <- nrow(phy$edge)
+    nNode <- phy$Nnode
+    .C("AllKids", as.integer(phy$edge[,2]), as.integer(phy$edge[,1]), 
+       as.integer(nTips), as.integer(nNode), as.integer(lp), integer(lp), 
+       integer(nNode+1L),integer(nNode))
 } 
 
 
 coph <- function(x, path=FALSE){ 
     if (is.null(attr(x, "order")) || attr(x, "order") == "cladewise") 
         x <- reorder(x, "postorder")
-    nTips = as.integer(length(x$tip.label))   
-    parents = as.integer(x$edge[,1]) 
-    kids = as.integer(x$edge[,2])
-    lp= as.integer(length(parents))
-    nNode = as.integer(x$Nnode)
-    m = as.integer(max(x$edge))
-    el = double(m)
+    nTips <- as.integer(length(x$tip.label))   
+    parents <- as.integer(x$edge[,1]) 
+    kids <- as.integer(x$edge[,2])
+    lp <- as.integer(length(parents))
+    nNode <- as.integer(x$Nnode)
+    m <- as.integer(max(x$edge))
+    el <- double(m)
     if(path) el <- rep(1.0, m)
-    else el[kids] = x$edge.length
-    dm <- .C("C_cophenetic", kids, parents, as.double(el), lp, m, nTips, nNode, double(nTips*(nTips-1L)/2L))[[8]]
+    else el[kids] <- x$edge.length
+    dm <- .C("C_cophenetic", kids, parents, as.double(el), lp, m, nTips, nNode, 
+             double(nTips*(nTips-1L)/2L))[[8]]
     attr(dm, "Size") <- nTips
     attr(dm, "Labels") <- x$tip.label
     attr(dm, "Diag") <- FALSE
@@ -72,10 +74,9 @@ cophenetic.networx <- function(x){
 SHORTwise <- function (x, nTips, delete=FALSE) 
 {
     v <- 1:nTips
-#    l <- sapply(x, length)
     l <- lengths(x)
-    lv = floor(nTips/2)  
-    for (i in 1:length(x)) { 
+    lv <- floor(nTips/2)  
+    for (i in seq_along(x)) { 
         if(l[i]>lv){
             y <- x[[i]]
             x[[i]] <- v[-y]
@@ -97,7 +98,7 @@ oneWise <- function (x, nTips=NULL)
 {
     if(is.null(nTips))nTips <- length(x[[1L]])
     v <- 1:nTips
-    for (i in 1:length(x)) {
+    for (i in seq_along(x)) {
         y <- x[[i]]
         if (y[1] != 1) 
             y <- v[-y]
@@ -109,6 +110,20 @@ oneWise <- function (x, nTips=NULL)
 }
 
 
+zeroWise <- function (x, nTips=NULL) 
+{
+    if(is.null(nTips))nTips <- length(x[[1L]])
+    v <- 1:nTips
+    for (i in seq_along(x)) {
+        y <- x[[i]]
+        if (y[1] == 1)  
+            y <- v[-y]
+        x[[i]] <- y      
+    }
+    x
+}
+
+
 ## @aliases treedist RF.dist wRF.dist KF.dist path.dist sprdist SPR.dist
 
 #' Distances between trees
@@ -132,9 +147,9 @@ oneWise <- function (x, nTips=NULL)
 #' maximal possible distance \eqn{i(T_1) + i(T_2)}. If both trees are unrooted
 #' and binary this value is \eqn{2n-6}.
 #' 
-#' Functions like \code{RF.dist} returns the Robinson-Foulds distance (Robinson and Foulds 1981)
-#' between either 2 trees or computes a matrix of all pairwise distances if a
-#' \code{multiPhylo} object is given. 
+#' Functions like \code{RF.dist} returns the Robinson-Foulds distance (Robinson 
+#' and Foulds 1981) between either 2 trees or computes a matrix of all pairwise
+#' distances if a \code{multiPhylo} object is given. 
 #' 
 #' For large number of trees the distance functions can use a lot of memory!
 #' 
@@ -156,7 +171,7 @@ oneWise <- function (x, nTips=NULL)
 #' @author Klaus P. Schliep \email{klaus.schliep@@gmail.com},
 #' Leonardo de Oliveira Martins
 #' @seealso \code{\link[ape]{dist.topo}}, \code{\link{nni}},
-#' \code{\link{superTree}}
+#' \code{\link{superTree}}, \code{\link{mast}}
 #' @references de Oliveira Martins L., Leal E., Kishino H. (2008)
 #' \emph{Phylogenetic Detection of Recombination with a Bayesian Prior on the
 #' Distance between Trees}. PLoS ONE \bold{3(7)}. e2651. doi:
@@ -195,8 +210,11 @@ oneWise <- function (x, nTips=NULL)
 #' @export treedist
 treedist <- function (tree1, tree2, check.labels=TRUE) 
 {
-    tree1 = unroot(tree1)
-    tree2 = unroot(tree2)
+    if(has.singles(tree1)) tree1 <- collapse.singles(tree1)
+    if(has.singles(tree2)) tree2 <- collapse.singles(tree2)
+    
+    tree1 <- unroot(tree1)
+    tree2 <- unroot(tree2)
     
     if (check.labels) {
         ind <- match(tree1$tip.label, tree2$tip.label)
@@ -204,66 +222,66 @@ treedist <- function (tree1, tree2, check.labels=TRUE)
             length(tree2$tip.label))
             stop("trees have different labels")
         tree2$tip.label <- tree2$tip.label[ind]
-        ind2 <- match(1:length(ind), tree2$edge[, 2])
+        ind2 <- match(seq_along(ind), tree2$edge[, 2])
         tree2$edge[ind2, 2] <- order(ind)
     }
     
-    tree1 = reorder(tree1, "postorder")
-    tree2 = reorder(tree2, "postorder")
+    tree1 <- reorder(tree1, "postorder")
+    tree2 <- reorder(tree2, "postorder")
     
-    symmetric.difference = NULL
-    branch.score.difference = NULL
-    path.difference = NULL
-    quadratic.path.difference = NULL
-    if(!is.binary.tree(tree1) | !is.binary.tree(tree2))message("Trees are not binary!")
+    symmetric.difference <- NULL
+    branch.score.difference <- NULL
+    path.difference <- NULL
+    quadratic.path.difference <- NULL
+    if(!is.binary(tree1) | !is.binary(tree2))message("Trees are not binary!")
     
-    bp1 = bip(tree1)
-    bp2 = bip(tree2)
+    bp1 <- bip(tree1)
+    bp2 <- bip(tree2)
     bp1 <- SHORTwise(bp1, length(tree1$tip.label))
     bp2 <- SHORTwise(bp2, length(tree2$tip.label))
     bp1 <- sapply(bp1, paste, collapse = "_")
     bp2 <- sapply(bp2, paste, collapse = "_")
     
-    l = length(tree1$tip.label)
+    l <- length(tree1$tip.label)
     
     if (!is.null(tree1$edge.length) & !is.null(tree2$edge.length)) {      
-        dv1 = coph(tree1)
-        dv2 = coph(tree2)
-        quadratic.path.difference = sqrt(sum((dv1 - dv2)^2))
+        dv1 <- coph(tree1)
+        dv2 <- coph(tree2)
+        quadratic.path.difference <- sqrt(sum((dv1 - dv2)^2))
         
     }
     
-    RF = sum(match(bp1, bp2, nomatch=0L)==0L) + sum(match(bp2, bp1, nomatch=0L)==0L)
+    RF <- sum(match(bp1, bp2, nomatch=0L)==0L) + sum(match(bp2, bp1, nomatch=0L)==0L)
     
-    symmetric.difference = RF #2 * (p - sum(r1))
+    symmetric.difference <- RF #2 * (p - sum(r1))
     if (!is.null(tree1$edge.length) & !is.null(tree2$edge.length)) {
-        w1 = numeric(max(tree1$edge))
-        w2 = numeric(max(tree2$edge))
-        w1[tree1$edge[,2]] = tree1$edge.length
-        w2[tree2$edge[,2]] = tree2$edge.length
+        w1 <- numeric(max(tree1$edge))
+        w2 <- numeric(max(tree2$edge))
+        w1[tree1$edge[,2]] <- tree1$edge.length
+        w2[tree2$edge[,2]] <- tree2$edge.length
         
-        v1 = tree1$edge.length
-        v2 = tree2$edge.length
+        v1 <- tree1$edge.length
+        v2 <- tree2$edge.length
         
-        ind3 = match(bp1, bp2, nomatch=0L)
-        ind4 = ind3[ind3>0]
-        ind3 = which(ind3>0)
+        ind3 <- match(bp1, bp2, nomatch=0L)
+        ind4 <- ind3[ind3>0]
+        ind3 <- which(ind3>0)
         
-        s1 = sum((w1[ind3] - w2[ind4])^2)
+        s1 <- sum((w1[ind3] - w2[ind4])^2)
         
-        s2 = sum(w1[-ind3]^2)
-        s3 = sum(w2[-ind4]^2)
-        branch.score.difference = sqrt(s1 + s2 + s3)
+        s2 <- sum(w1[-ind3]^2)
+        s3 <- sum(w2[-ind4]^2)
+        branch.score.difference <- sqrt(s1 + s2 + s3)
     }
     
-    tree1$edge.length = rep(1, nrow(tree1$edge))
-    tree2$edge.length = rep(1, nrow(tree2$edge))
+    tree1$edge.length <- rep(1, nrow(tree1$edge))
+    tree2$edge.length <- rep(1, nrow(tree2$edge))
     
-    dt1 = coph(tree1)
-    dt2 = coph(tree2)  
-    path.difference = sqrt(sum((dt1 - dt2)^2))
+    dt1 <- coph(tree1)
+    dt2 <- coph(tree2)  
+    path.difference <- sqrt(sum((dt1 - dt2)^2))
     
-    result = c(symmetric.difference = symmetric.difference, 
+    result <- c(symmetric.difference = symmetric.difference, 
                branch.score.difference = branch.score.difference, 
                path.difference = path.difference, 
                quadratic.path.difference = quadratic.path.difference)
@@ -278,29 +296,35 @@ treedist <- function (tree1, tree2, check.labels=TRUE)
 #' @export
 sprdist <- function (tree1, tree2) 
 {
-    tree1 = unroot(tree1)
-    tree2 = unroot(tree2)
-    lt1 = length(tree1$tip.label)
-    lt2 = length(tree2$tip.label)
-    # checking labels is obligatory for spr (user should prune one of them beforehand?)         
+    if(has.singles(tree1)) tree1 <- collapse.singles(tree1)
+    if(has.singles(tree2)) tree2 <- collapse.singles(tree2)
+    tree1 <- unroot(tree1)
+    tree2 <- unroot(tree2)
+    lt1 <- length(tree1$tip.label)
+    lt2 <- length(tree2$tip.label)
+    # checking labels is obligatory for spr (user should prune one of them 
+    # beforehand?)         
     ind <- match(tree1$tip.label, tree2$tip.label)
     if (any(is.na(ind)) | lt1 != lt2 )  stop("trees have different labels")
     tree2$tip.label <- tree2$tip.label[ind]
-    ind2 <- match(1:length(ind), tree2$edge[, 2])
+    ind2 <- match(seq_along(ind), tree2$edge[, 2])
     tree2$edge[ind2, 2] <- order(ind)
-    # same as in original treedist (will create list of strings with shorter side of splits)
-    tree1 = reorder(tree1, "postorder")
-    tree2 = reorder(tree2, "postorder")
-    if(!is.binary.tree(tree1) | !is.binary.tree(tree2))message("Trees are not binary!")
+    # same as in original treedist (will create list of strings with shorter 
+    # side of splits)
+    tree1 <- reorder(tree1, "postorder")
+    tree2 <- reorder(tree2, "postorder")
+    if(!is.binary(tree1) | !is.binary(tree2))message("Trees are not binary!")
     # possibly replace bip with bipart    
-    bp1 = bip(tree1); bp1 <- SHORTwise(bp1, lt1)
-    bp2 = bip(tree2); bp2 <- SHORTwise(bp2, lt2)
+    bp1 <- bip(tree1)
+    bp1 <- SHORTwise(bp1, lt1)
+    bp2 <- bip(tree2)
+    bp2 <- SHORTwise(bp2, lt2)
     
     bp1 <- bp1[ lengths(bp1)>1 ] # only internal nodes 
     bp2 <- bp2[ lengths(bp2)>1 ] 
     if (length(bp1) != length(bp2)) stop ("number of bipartitions given to C_sprdist are not the same")
     # OBS: SPR distance works w/ incompatible splits only, but it needs common cherries (to replace by single leaf)
-    spr <- .Call("C_sprdist", bp1, bp2, lt1);
+    spr <- .Call("C_sprdist", bp1, bp2, lt1)
     names(spr) <- c("spr", "spr_extra", "rf", "hdist")
 #    list("spr" = spr[1], "spr_extra" = spr[2], "rf" = spr[3], "hdist"= spr[4]);
     spr
@@ -311,6 +335,7 @@ SPR1 <- function(trees){
     trees <- .compressTipLabel(trees)
     trees <- .uncompressTipLabel(trees)
     trees <- lapply(trees, unroot)
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
     trees <- lapply(trees, reorder, "postorder")
     
     nTips <- length(trees[[1]]$tip.label)
@@ -346,11 +371,13 @@ SPR2 <- function(tree, trees){
     trees <- .compressTipLabel(trees)
     tree <- checkLabels(tree, attr(trees, "TipLabel"))
     trees <- .uncompressTipLabel(trees)
-    if (any(sapply(trees, is.rooted))) {
-        trees <- lapply(trees, unroot)
+    if (any(is.rooted(trees))) {
+        trees <- unroot(trees)
     }
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
     trees <- lapply(trees, reorder, "postorder")
-    tree <- unroot(tree)                
+    tree <- unroot(tree)      
+    if(has.singles(tree)) tree <- collapse.singles(tree)
     nTips <- length(tree$tip.label)
     
     fun <- function(x, nTips){
@@ -384,8 +411,8 @@ SPR.dist <- function(tree1, tree2=NULL){
 
 
 wRF0 <- function(tree1, tree2, normalize=FALSE, check.labels=TRUE, rooted = FALSE){    
-    r1 = is.rooted(tree1)
-    r2 = is.rooted(tree2)
+    r1 <- is.rooted(tree1)
+    r2 <- is.rooted(tree2)
     if (r1 != r2) {
         message("one tree is unrooted, unrooted both")
     }
@@ -397,22 +424,24 @@ wRF0 <- function(tree1, tree2, normalize=FALSE, check.labels=TRUE, rooted = FALS
     }
     if (!r1 | !r2) {
         if (r1) 
-            tree1 = unroot(tree1)
+            tree1 <- unroot(tree1)
         if (r2) 
-            tree2 = unroot(tree2)
+            tree2 <- unroot(tree2)
     }
-    if (!is.binary.tree(tree1) | !is.binary.tree(tree2)) 
+    if (!is.binary(tree1) | !is.binary(tree2)) 
         message("Trees are not binary!")
     if (check.labels) {
         ind <- match(tree1$tip.label, tree2$tip.label)
         if (any(is.na(ind)) | length(tree1$tip.label) != length(tree2$tip.label)) 
             stop("trees have different labels")
         tree2$tip.label <- tree2$tip.label[ind]
-        ind2 <- match(1:length(ind), tree2$edge[, 2])
+        ind2 <- match(seq_along(ind), tree2$edge[, 2])
         tree2$edge[ind2, 2] <- order(ind)
     }
-    bp1 = bip(tree1)
-    bp2 = bip(tree2)
+    if(has.singles(tree1)) tree1 <- collapse.singles(tree1)
+    if(has.singles(tree2)) tree2 <- collapse.singles(tree2)
+    bp1 <- bip(tree1)
+    bp2 <- bip(tree2)
     if (!rooted) {
         bp1 <- SHORTwise(bp1, length(tree1$tip.label))
         bp2 <- SHORTwise(bp2, length(tree2$tip.label))
@@ -439,17 +468,28 @@ wRF0 <- function(tree1, tree2, normalize=FALSE, check.labels=TRUE, rooted = FALS
 }
 
 
-wRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE){    
+wRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE, rooted=FALSE){    
     if(check.labels){
         trees <- .compressTipLabel(trees)
         tree <- checkLabels(tree, attr(trees, "TipLabel"))
     }    
     trees <- .uncompressTipLabel(trees)
-    unclass(trees) 
     
-    if (any(sapply(trees, is.rooted))) {
-        trees <- lapply(trees, unroot)
+    if (rooted & any(!is.rooted(trees))){
+        warning("Some trees are unrooted, unrooted all")
+        rooted <- FALSE
     }
+
+    if(!rooted){
+        if (any(is.rooted(trees))) {
+            trees <- unroot(trees) 
+        }
+    }
+    
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
+    if(has.singles(tree)) tree <- collapse.singles(tree)
+    
+    unclass(trees) 
     
     nTips <- length(tree$tip.label)
     
@@ -466,12 +506,19 @@ wRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE){
         bp <- sapply(bp, paste, collapse = "_")
         bp
     }
-    BP <- lapply(trees, fun2, nTips)
+    fun3 <- function(x, nTips){
+        bp <- bip(x)
+        bp <- sapply(bp, paste, collapse = "_")
+        bp
+    }
+    if(rooted) BP <- lapply(trees, fun3, nTips)
+    else BP <- lapply(trees, fun2, nTips)
     
-    if(is.rooted(tree)) tree <- unroot(tree)
-    bp = bip(tree)
+    if(!rooted & is.rooted(tree)) tree <- unroot(tree)
+        
+    bp <- bip(tree)
     
-    bp <- SHORTwise(bp, nTips)
+    if(!rooted) bp <- SHORTwise(bp, nTips)
     bp <- sapply(bp, paste, collapse = "_")
     
     w <- numeric(max(tree$edge))
@@ -481,14 +528,14 @@ wRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE){
     wRF <- numeric(l)
     
     for(i in 1:l){
-        ind3 = fmatch(BP[[i]], bp, nomatch=0L)
-        ind4 = ind3[ind3>0]
-        ind3 = which(ind3>0)
+        ind3 <- fmatch(BP[[i]], bp, nomatch=0L)
+        ind4 <- ind3[ind3>0]
+        ind3 <- which(ind3>0)
         
-        s1 = sum(abs(W[[i]][ind3] - w[ind4]))
-        s2 = sum(W[[i]][-ind3])
-        s3 = sum(w[-ind4])
-        wRF[i] = (s1 + s2 + s3)
+        s1 <- sum(abs(W[[i]][ind3] - w[ind4]))
+        s2 <- sum(W[[i]][-ind3])
+        s3 <- sum(w[-ind4])
+        wRF[i] <- (s1 + s2 + s3)
     }
     if(normalize){
         sc <- sapply(trees, function(x)sum(x$edge.length)) + sum(tree$edge.length)
@@ -498,15 +545,23 @@ wRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE){
 }
 
 
-wRF1 <- function(trees, normalize=FALSE, check.labels = TRUE){
+wRF1 <- function(trees, normalize=FALSE, check.labels = TRUE, rooted=FALSE){
     if(check.labels) trees <- .compressTipLabel(trees)
     trees <- .uncompressTipLabel(trees)
-    unclass(trees)     
+    
+    if (rooted & any(!is.rooted(trees))){
+        warning("Some trees are unrooted, unrooted all")
+        rooted <- FALSE
+    }
+    if(!rooted){
+        if (any(is.rooted(trees))) {
+            trees <- unroot(trees) 
+        }
+    }
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
+    unclass(trees) 
     
     nTips <- length(trees[[1]]$tip.label)
-    if (any(sapply(trees, is.rooted))) {
-        trees <- lapply(trees, unroot)
-    }
     fun1 <- function(x){
         w <- numeric(max(x$edge))
         w[x$edge[,2]] <- x$edge.length
@@ -519,8 +574,14 @@ wRF1 <- function(trees, normalize=FALSE, check.labels = TRUE){
         bp <- sapply(bp, paste, collapse = "_")
         bp
     }
+    fun3 <- function(x, nTips){
+        bp <- bip(x)
+        bp <- sapply(bp, paste, collapse = "_")
+        bp
+    }
     if(normalize) sc <- sapply(trees, function(x)sum(x$edge.length)) 
-    BP <- lapply(trees, fun2, nTips)
+    if(rooted) BP <- lapply(trees, fun3, nTips)
+    else BP <- lapply(trees, fun2, nTips)
     k <- 1
     l <- length(trees)
     wRF <- numeric((l * (l - 1))/2)
@@ -528,12 +589,12 @@ wRF1 <- function(trees, normalize=FALSE, check.labels = TRUE){
         bp <- BP[[i]]
         w <- W[[i]]
         for (j in (i + 1):l){
-            ind3 = fmatch(BP[[j]], bp, nomatch=0L)
-            ind4 = ind3[ind3>0]
-            ind3 = which(ind3>0)
-            s1 = sum(abs(W[[j]][ind3] - w[ind4]))
-            s2 = sum(W[[j]][-ind3])
-            s3 = sum(w[-ind4])
+            ind3 <- fmatch(BP[[j]], bp, nomatch=0L)
+            ind4 <- ind3[ind3>0]
+            ind3 <- which(ind3>0)
+            s1 <- sum(abs(W[[j]][ind3] - w[ind4]))
+            s2 <- sum(W[[j]][-ind3])
+            s3 <- sum(w[-ind4])
             wRF[k] <- (s1 + s2 + s3)
             if(normalize) wRF[k] <- wRF[k] / (sc[i] + sc[j])
             k=k+1
@@ -550,7 +611,7 @@ wRF1 <- function(trees, normalize=FALSE, check.labels = TRUE){
 
 
 
-mRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE){
+mRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE, rooted=FALSE){
     if (!inherits(trees,"multiPhylo")) 
         stop("trees should be an object of class \"multiPhylo\"")
     if (!inherits(tree,"phylo")) 
@@ -562,34 +623,36 @@ mRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE){
         if (any(is.na(ind)) | length(tipLabel) != length(tree$tip.label))
             stop("trees have different labels")
         tree$tip.label <- tree$tip.label[ind]
-        ind2 <- match(1:length(ind), tree$edge[, 2])
+        ind2 <- match(seq_along(ind), tree$edge[, 2])
         tree$edge[ind2, 2] <- order(ind)
     }
     nTips <- length(tipLabel)
     l <- length(trees)
     RF <- numeric(l)
     trees <- .uncompressTipLabel(trees)
-    #    n <- length(attr(trees, "TipLabel"))
-    trees <- unclass(trees)
-    if (any(sapply(trees, is.rooted))) {
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
+    if(has.singles(tree)) tree <- collapse.singles(tree)
+    
+#    trees <- unclass(trees)
+    if(!rooted & any(is.rooted(trees))) {
         message("Some trees are rooted. Unrooting all trees.\n")
-        trees <- lapply(trees, unroot)
+        trees <- unroot(trees)
     }
-    if(is.rooted(tree)) tree <- unroot(tree)
-    if (any(sapply(trees, function(x) !is.binary.tree(x)))) {
+    if(!rooted & is.rooted(tree))tree <- unroot(tree)
+    if (any(!is.binary(trees))) {
         message("Some trees are not binary. Result may not what you expect!")
     }
     tree <- reorder(tree, "postorder")
-    trees <- lapply(trees, reorder, "postorder")
+    trees <- reorder(trees, "postorder")
     xx <- lapply(trees, bipart)  
-    xx <- lapply(xx, SHORTwise, nTips)
+    if(!rooted)xx <- lapply(xx, SHORTwise, nTips)
     xx <- lapply(xx,function(x)sapply(x, paste, collapse="_"))
     yy <- bipart(tree)  
-    yy <- SHORTwise(yy, nTips)
+    if(!rooted)yy <- SHORTwise(yy, nTips)
     yy <- sapply(yy, paste, collapse="_")
     
     NnodeT <- Nnode(tree)
-    Nnodes <- sapply(trees, Nnode)
+    Nnodes <- Nnode(trees)
     
     for (i in 1:l){   
         RF[i] <- Nnodes[i] + NnodeT - 2 * sum(fmatch(xx[[i]], yy, nomatch=0L)>0L)
@@ -598,13 +661,13 @@ mRF2 <- function(tree, trees, normalize=FALSE, check.labels = TRUE){
     if(!is.null(names(trees)))names(RF) <- names(trees)
     if(!normalize)return(RF)
     else{
-        sc <- sapply(trees, Nnode) + Nnode(tree) - 2
+        sc <- Nnode(trees) + Nnode(tree) - 2
         return(RF/sc)
     }
 }
 
 
-mRF<-function(trees, normalize=FALSE){
+mRF<-function(trees, normalize=FALSE, rooted=FALSE){
     if (!inherits(trees,"multiPhylo")) 
         stop("trees should be an object of class \"multiPhylo\"")
     trees <- .compressTipLabel(trees)
@@ -612,25 +675,41 @@ mRF<-function(trees, normalize=FALSE){
     nTips <- length(tipLabel)
     l <- length(trees)
     RF <- numeric((l * (l - 1))/2)
-    trees <- .uncompressTipLabel(trees)
-    #    n <- length(attr(trees, "TipLabel"))
-    trees <- unclass(trees)
-    if (any(sapply(trees, is.rooted))) {
-        message("Some trees are rooted. Unrooting all trees.\n")
-        trees <- lapply(trees, unroot)
+    
+    if (rooted & any(!is.rooted(trees))){
+        warning("Some trees are unrooted, unrooted all")
+        rooted <- FALSE
     }
-    if (any(sapply(trees, function(x) !is.binary.tree(x)))) {
+    if(!rooted){
+        if (any(is.rooted(trees))) {
+            trees <- unroot(trees) 
+        }
+    }
+    
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
+
+    #    n <- length(attr(trees, "TipLabel"))
+
+#    if (any(sapply(trees, is.rooted))) {
+#        message("Some trees are rooted. Unrooting all trees.\n")
+#        trees <- lapply(trees, unroot)
+#    }
+    if (any(!is.binary(trees))) {
         message("Some trees are not binary. Result may not what you expect!")
     }
-    trees <- lapply(trees, reorder, "postorder")
+#    trees <- reorder(trees, "postorder")
+#    trees <- lapply(trees, reorder, "postorder")
+    trees <- .uncompressTipLabel(trees)    
+    trees <- unclass(trees)
+    
     xx <- lapply(trees, bipart)  
-    xx <- lapply(xx, SHORTwise, nTips)
+    if(!rooted) xx <- lapply(xx, SHORTwise, nTips)
     xx <- lapply(xx,function(x)sapply(x, paste, collapse="_")) 
     # returns list of character vectors
     Nnodes <- sapply(trees, Nnode)
     k=1
     for (i in 1:(l - 1)){
-        tmp = xx[[i]]        
+        tmp <- xx[[i]]        
         for (j in (i + 1):l){
             RF[k] <- Nnodes[i] + Nnodes[j] - 2 * sum(fmatch(xx[[j]], tmp, nomatch=0L)>0L)
 #            RF[k] <- sum(match(xx[[j]], tmp, nomatch=0L)==0L) + sum(match(tmp, xx[[j]], nomatch=0L)==0L)
@@ -648,8 +727,10 @@ mRF<-function(trees, normalize=FALSE){
 
 
 RF0 <- function(tree1, tree2=NULL, normalize=FALSE, check.labels = TRUE, rooted=FALSE){   
-    r1 = is.rooted(tree1)
-    r2 = is.rooted(tree2)
+    if(has.singles(tree1)) tree1 <- collapse.singles(tree1)
+    if(has.singles(tree2)) tree2 <- collapse.singles(tree2)
+    r1 <- is.rooted(tree1)
+    r2 <- is.rooted(tree2)
     if(!rooted){
         if(r1) {
             tree1<-unroot(tree1)
@@ -675,18 +756,18 @@ RF0 <- function(tree1, tree2=NULL, normalize=FALSE, check.labels = TRUE, rooted=
             stop("trees have different labels")
         tree2$tip.label <- tree2$tip.label[ind]
         #       tree2$edge[match(ind, tree2$edge[, 2]), 2] <- 1:length(ind)
-        ind2 <- match(1:length(ind), tree2$edge[, 2])
+        ind2 <- match(seq_along(ind), tree2$edge[, 2])
         tree2$edge[ind2, 2] <- order(ind)
     }
-    if(!is.binary.tree(tree1) | !is.binary.tree(tree2))message("Trees are not binary!")
-    bp1 = bipart(tree1)
-    bp2 = bipart(tree2)
+    if(!is.binary(tree1) | !is.binary(tree2))message("Trees are not binary!")
+    bp1 <- bipart(tree1)
+    bp2 <- bipart(tree2)
     nTips <- length(tree1$tip.label)
     if(!rooted){
         bp1 <- SHORTwise(bp1, nTips)
         bp2 <- SHORTwise(bp2, nTips)    
     }
-    RF = sum(match(bp1, bp2, nomatch=0L)==0L) + sum(match(bp2, bp1, nomatch=0L)==0L)
+    RF <- sum(match(bp1, bp2, nomatch=0L)==0L) + sum(match(bp2, bp1, nomatch=0L)==0L)
     if(normalize) RF <- RF / (Nnode(tree1) + Nnode(tree2) - 2)
     RF
 }
@@ -697,9 +778,9 @@ RF0 <- function(tree1, tree2=NULL, normalize=FALSE, check.labels = TRUE, rooted=
 RF.dist <- function(tree1, tree2=NULL, normalize=FALSE, check.labels = TRUE, rooted=FALSE)
 {
     if(class(tree1)=="phylo" && class(tree2)=="phylo")return(RF0(tree1, tree2, normalize, check.labels, rooted))
-    if(class(tree1)=="multiPhylo" && is.null(tree2))return(mRF(tree1, normalize)) 
-    if(class(tree1)=="phylo" && class(tree2)=="multiPhylo")return(mRF2(tree1, tree2, normalize, check.labels))
-    if(class(tree2)=="phylo" && class(tree1)=="multiPhylo")return(mRF2(tree2, tree1, normalize, check.labels))
+    if(class(tree1)=="multiPhylo" && is.null(tree2))return(mRF(tree1, normalize, rooted)) 
+    if(class(tree1)=="phylo" && class(tree2)=="multiPhylo")return(mRF2(tree1, tree2, normalize, check.labels, rooted))
+    if(class(tree2)=="phylo" && class(tree1)=="multiPhylo")return(mRF2(tree2, tree1, normalize, check.labels, rooted))
     else return(NULL)
 }
 
@@ -708,23 +789,39 @@ RF.dist <- function(tree1, tree2=NULL, normalize=FALSE, check.labels = TRUE, roo
 #' @export
 wRF.dist <- function(tree1, tree2=NULL, normalize=FALSE, check.labels = TRUE, rooted=FALSE){
     if(class(tree1)=="phylo" && class(tree2)=="phylo")return(wRF0(tree1, tree2, normalize, check.labels, rooted))
-    if(class(tree1)=="multiPhylo" && is.null(tree2))return(wRF1(tree1, normalize, check.labels))
-    
-    if(class(tree1)=="phylo" && class(tree2)=="multiPhylo")return(wRF2(tree1, tree2, normalize, check.labels))
-    if(class(tree2)=="phylo" && class(tree1)=="multiPhylo")return(wRF2(tree2, tree1, normalize, check.labels))
+    if(class(tree1)=="multiPhylo" && is.null(tree2))return(wRF1(tree1, normalize, check.labels, rooted))
+    if(class(tree1)=="phylo" && class(tree2)=="multiPhylo")return(wRF2(tree1, tree2, normalize, check.labels, rooted))
+    if(class(tree2)=="phylo" && class(tree1)=="multiPhylo")return(wRF2(tree2, tree1, normalize, check.labels, rooted))
     else return(NULL)        
 }
 
 
-kf0 <- function(tree1, tree2, check.labels = TRUE){    
+kf0 <- function(tree1, tree2, check.labels = TRUE, rooted=FALSE){    
     if(check.labels)tree2 <- checkLabels(tree2, tree1$tip.label)
-    if(is.rooted(tree1)) tree1 <- unroot(tree1)
-    if(is.rooted(tree2)) tree2 <- unroot(tree2)
-    bp1 = bip(tree1)
-    bp2 = bip(tree2)
+    if(has.singles(tree1)) tree1 <- collapse.singles(tree1)
+    if(has.singles(tree2)) tree2 <- collapse.singles(tree2)
+    r1 <- is.rooted(tree1)
+    r2 <- is.rooted(tree2)
+    if(!rooted){
+        if(r1) tree1<-unroot(tree1)
+        if(r2) tree2<-unroot(tree2)
+    }
+    else{
+        if(r1 != r2) {
+            message("one tree is unrooted, unrooted both")
+            tree1 <- unroot(tree1)
+            tree2 <- unroot(tree2)
+            r1 <- r2 <- FALSE
+        }
+    }
     
-    bp1 <- SHORTwise(bp1, length(tree1$tip.label))
-    bp2 <- SHORTwise(bp2, length(tree2$tip.label))
+    bp1 <- bip(tree1)
+    bp2 <- bip(tree2)
+    
+    if(!rooted){
+        bp1 <- SHORTwise(bp1, length(tree1$tip.label))
+        bp2 <- SHORTwise(bp2, length(tree2$tip.label))
+    }
     bp1 <- sapply(bp1, paste, collapse = "_")
     bp2 <- sapply(bp2, paste, collapse = "_")
     
@@ -733,29 +830,42 @@ kf0 <- function(tree1, tree2, check.labels = TRUE){
     w1[tree1$edge[,2]] <- tree1$edge.length
     w2[tree2$edge[,2]] <- tree2$edge.length
         
-    ind3 = match(bp1, bp2, nomatch=0L)
-    ind4 = ind3[ind3>0]
-    ind3 = which(ind3>0)
+    ind3 <- match(bp1, bp2, nomatch=0L)
+    ind4 <- ind3[ind3>0]
+    ind3 <- which(ind3>0)
         
-    s1 = sum((w1[ind3] - w2[ind4])^2)
-    s2 = sum(w1[-ind3]^2)
-    s3 = sum(w2[-ind4]^2)
-    branch.score.difference = sqrt(s1 + s2 + s3)
+    s1 <- sum((w1[ind3] - w2[ind4])^2)
+    s2 <- sum(w1[-ind3]^2)
+    s3 <- sum(w2[-ind4]^2)
+    branch.score.difference <- sqrt(s1 + s2 + s3)
     branch.score.difference
 }
 
 
-kf1 <- function(tree, trees, check.labels = TRUE){    
+kf1 <- function(tree, trees, check.labels = TRUE, rooted=FALSE){    
     if(check.labels){
         trees <- .compressTipLabel(trees)
         tree <- checkLabels(tree, attr(trees, "TipLabel"))
     }    
     trees <- .uncompressTipLabel(trees)
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
+    if(has.singles(tree)) tree <- collapse.singles(tree)
+    
+    if (rooted & any(!is.rooted(trees))){
+        warning("Some trees are unrooted, unrooted all")
+        rooted <- FALSE
+    }
+    if(!rooted){
+        if (any(is.rooted(trees))) {
+            trees <- unroot(trees) 
+        }
+    }
+    
     unclass(trees) 
     
-    if (any(sapply(trees, is.rooted))) {
-        trees <- lapply(trees, unroot)
-    }
+#    if (any(sapply(trees, is.rooted))) {
+#        trees <- lapply(trees, unroot)
+#    }
     
     nTips <- length(tree$tip.label)
     
@@ -772,13 +882,17 @@ kf1 <- function(tree, trees, check.labels = TRUE){
         bp <- sapply(bp, paste, collapse = "_")
         bp
     }
-    BP <- lapply(trees, fun2, nTips)
+    fun3 <- function(x, nTips){
+        bp <- bip(x)
+        bp <- sapply(bp, paste, collapse = "_")
+        bp
+    }
+    if(rooted) BP <- lapply(trees, fun3, nTips)
+    else BP <- lapply(trees, fun2, nTips)
     
-    
-    if(is.rooted(tree)) tree <- unroot(tree)
-    bp = bip(tree)
-    
-    bp <- SHORTwise(bp, nTips)
+    if(!rooted & is.rooted(tree)) tree <- unroot(tree)
+    bp <- bip(tree)
+    if(!rooted) bp <- SHORTwise(bp, nTips)
     bp <- sapply(bp, paste, collapse = "_")
 
     w <- numeric(max(tree$edge))
@@ -788,41 +902,61 @@ kf1 <- function(tree, trees, check.labels = TRUE){
     branch.score.difference <- numeric(l)
     
     for(i in 1:l){
-        ind3 = fmatch(BP[[i]], bp, nomatch=0L)
-        ind4 = ind3[ind3>0]
-        ind3 = which(ind3>0)
+        ind3 <- fmatch(BP[[i]], bp, nomatch=0L)
+        ind4 <- ind3[ind3>0]
+        ind3 <- which(ind3>0)
     
-        s1 = sum((W[[i]][ind3] - w[ind4])^2)
-        s2 = sum(W[[i]][-ind3]^2)
-        s3 = sum(w[-ind4]^2)
-        branch.score.difference[i] = sqrt(s1 + s2 + s3)
+        s1 <- sum((W[[i]][ind3] - w[ind4])^2)
+        s2 <- sum(W[[i]][-ind3]^2)
+        s3 <- sum(w[-ind4]^2)
+        branch.score.difference[i] <- sqrt(s1 + s2 + s3)
     }
     branch.score.difference
 }
 
 
-kf2 <- function(trees, check.labels = TRUE){
+kf2 <- function(trees, check.labels = TRUE, rooted=FALSE){
     if(check.labels) trees <- .compressTipLabel(trees)
     trees <- .uncompressTipLabel(trees)
-    unclass(trees)     
+#    unclass(trees)     
     
+    if(any(has.singles(trees))) trees <- lapply(trees, collapse.singles)
+
     nTips <- length(trees[[1]]$tip.label)
-    if (any(sapply(trees, is.rooted))) {
-        trees <- lapply(trees, unroot)
+#    if (any(sapply(trees, is.rooted))) {
+#        trees <- lapply(trees, unroot)
+#    }
+    if (rooted & any(!is.rooted(trees))){
+        warning("Some trees are unrooted, unrooted all")
+        rooted <- FALSE
     }
+    if (!rooted & any(is.rooted(trees))) {
+        trees <- unroot(trees)
+    }
+    
+    unclass(trees)    
     fun1 <- function(x){
         w <- numeric(max(x$edge))
         w[x$edge[,2]] <- x$edge.length
         w
     }
     W <- lapply(trees, fun1)
+    
+    
     fun2 <- function(x, nTips){
         bp <- bip(x)
         bp <- SHORTwise(bp, nTips)
         bp <- sapply(bp, paste, collapse = "_")
         bp
     }
-    BP <- lapply(trees, fun2, nTips)
+    fun3 <- function(x, nTips){
+        bp <- bip(x)
+        bp <- sapply(bp, paste, collapse = "_")
+        bp
+    }
+    if(rooted) BP <- lapply(trees, fun3, nTips)
+    else BP <- lapply(trees, fun2, nTips)
+    
     k <- 1
     l <- length(trees)
     KF <- numeric((l * (l - 1))/2)
@@ -830,14 +964,14 @@ kf2 <- function(trees, check.labels = TRUE){
         bp <- BP[[i]]
         w <- W[[i]]
         for (j in (i + 1):l){
-            ind3 = fmatch(BP[[j]], bp, nomatch=0L)
-            ind4 = ind3[ind3>0]
-            ind3 = which(ind3>0)
-            s1 = sum((W[[j]][ind3] - w[ind4])^2)
-            s2 = sum(W[[j]][-ind3]^2)
-            s3 = sum(w[-ind4]^2)
+            ind3 <- fmatch(BP[[j]], bp, nomatch=0L)
+            ind4 <- ind3[ind3>0]
+            ind3 <- which(ind3>0)
+            s1 <- sum((W[[j]][ind3] - w[ind4])^2)
+            s2 <- sum(W[[j]][-ind3]^2)
+            s3 <- sum(w[-ind4]^2)
             KF[k] <- sqrt(s1 + s2 + s3)
-            k=k+1
+            k <- k+1
         }
     }
     attr(KF, "Size") <- l
@@ -852,10 +986,10 @@ kf2 <- function(trees, check.labels = TRUE){
 #' @rdname treedist
 #' @export
 KF.dist <- function(tree1, tree2=NULL, check.labels = TRUE, rooted=FALSE){
-    if(inherits(tree1, "multiPhylo") && is.null(tree2))return(kf2(tree1)) 
-    if(inherits(tree1, "phylo") && inherits(tree2, "phylo"))return(kf0(tree1, tree2, check.labels))
-    if(inherits(tree1, "phylo") && inherits(tree2, "multiPhylo"))return(kf1(tree1, tree2, check.labels))
-    if(inherits(tree2, "phylo") && inherits(tree1, "multiPhylo"))return(kf1(tree2, tree1,check.labels))
+    if(inherits(tree1, "multiPhylo") && is.null(tree2))return(kf2(tree1, rooted=rooted)) 
+    if(inherits(tree1, "phylo") && inherits(tree2, "phylo"))return(kf0(tree1, tree2, check.labels, rooted))
+    if(inherits(tree1, "phylo") && inherits(tree2, "multiPhylo"))return(kf1(tree1, tree2, check.labels, rooted))
+    if(inherits(tree2, "phylo") && inherits(tree1, "multiPhylo"))return(kf1(tree2, tree1,check.labels, rooted))
     return(NULL)
 }
 
@@ -896,8 +1030,8 @@ pd0 <- function(tree1, tree2, check.labels=TRUE, path=TRUE){
     }    
 #    n <- nrow(tree1$edge)
 #    tree1$edge.length <- tree2$edge.length <- rep(1, n)
-    dt1 = coph(tree1, path)
-    dt2 = coph(tree2, path)  
+    dt1 <- coph(tree1, path)
+    dt2 <- coph(tree2, path)  
     sqrt(sum((dt1 - dt2)^2))
 }
 
@@ -908,12 +1042,12 @@ pd1 <- function(tree, trees, check.labels=TRUE, path=TRUE){
         tree <- checkLabels(tree, attr(trees, "TipLabel"))
     }    
     trees <- .uncompressTipLabel(trees)
-    unclass(trees)
     if(path){
-        trees <- lapply(trees, unroot)
+        trees <- unroot(trees)
         tree <- unroot(tree)
     }    
-    trees <- lapply(trees, reorder, "postorder")
+    trees <- reorder(trees, "postorder")
+    unclass(trees)
     l <- length(trees)
     dt <- coph(tree, path)
     res <- numeric(l)
@@ -927,10 +1061,10 @@ pd1 <- function(tree, trees, check.labels=TRUE, path=TRUE){
 pd2 <- function(trees, check.labels=TRUE, path=TRUE){
     if(check.labels) trees <- .compressTipLabel(trees)
     trees <- .uncompressTipLabel(trees)
-    unclass(trees) 
-    if(path)trees <- lapply(trees, unroot)
-    trees <- lapply(trees, reorder, "postorder")
+    if(path)trees <- unroot(trees)
+    trees <- reorder(trees, "postorder")
     l <- length(trees)
+    unclass(trees)
     CM <- lapply(trees, coph, path)
     res <- numeric(l)
     k <- 1 
